@@ -2,9 +2,9 @@
  * @licence app begin@
  * Copyright (C) 2011-2012  BMW AG
  *
- * This file is part of GENIVI Project Dlt Viewer.
+ * This file is part of COVESA Project Dlt Viewer.
  *
- * Contributions are licensed to the GENIVI Alliance under one or more
+ * Contributions are licensed to the COVESA Alliance under one or more
  * Contribution License Agreements.
  *
  * \copyright
@@ -15,7 +15,7 @@
  * \author Alexander Wenzel <alexander.aw.wenzel@bmw.de> 2011-2012
  *
  * \file qdlt.cpp
- * For further information see http://www.genivi.org/.
+ * For further information see http://www.covesa.global/.
  * @licence end@
  */
 
@@ -659,20 +659,21 @@ void QDltMsg::genMsg()
         standardheader.htyp |= DLT_HTYP_MSBF;
     }
     if(mode == DltModeVerbose) {
-        standardheader.len = DLT_HTOBE_16(sizeof(DltStandardHeader) + sizeof(DltExtendedHeader) + payload.size());
+        uint16_t standardheaderlen = sizeof(DltStandardHeader) + sizeof(DltExtendedHeader) + payload.size();
         standardheader.htyp |= DLT_HTYP_UEH;
         if(!ecuid.isEmpty()) {
             standardheader.htyp |= DLT_HTYP_WEID;
-            standardheader.len += sizeof(headerextra.ecu);
+            standardheaderlen += sizeof(headerextra.ecu);
         }
         if(sessionid!=0) {
             standardheader.htyp |= DLT_HTYP_WSID;
-            standardheader.len += sizeof(headerextra.seid);
+            standardheaderlen += sizeof(headerextra.seid);
         }
         if(timestamp!=0) {
             standardheader.htyp |= DLT_HTYP_WTMS;
-            standardheader.len += sizeof(headerextra.tmsp);
+            standardheaderlen += sizeof(headerextra.tmsp);
         }
+        standardheader.len = DLT_HTOBE_16(standardheaderlen);
     }
     else {
         standardheader.len = DLT_HTOBE_16(sizeof(DltStandardHeader) + payload.size());
