@@ -2,9 +2,9 @@
  * @licence app begin@
  * Copyright (C) 2011-2012  BMW AG
  *
- * This file is part of GENIVI Project Dlt Viewer.
+ * This file is part of COVESA Project Dlt Viewer.
  *
- * Contributions are licensed to the GENIVI Alliance under one or more
+ * Contributions are licensed to the COVESA Alliance under one or more
  * Contribution License Agreements.
  *
  * \copyright
@@ -15,7 +15,7 @@
  * \author Lassi Marttala <Lassi.LM.Marttala@partner.bmw.de
  *
  * \file dltsettingsmanager.cpp
- * For further information see http://www.genivi.org/.
+ * For further information see http://www.covesa.global/.
  * @licence end@
  */
 
@@ -156,6 +156,7 @@ void QDltSettingsManager::writeSettings()
     settings->setValue("windowState", windowState);
     settings->setValue("RefreshRate",RefreshRate);
     settings->setValue("StartUpMinimized",StartupMinimized);
+    settings->setValue("ThemeSettings", static_cast<int>(themeSelectionSettings));
 
     /* Temporary directory */
     settings->setValue("tempdir/tempUseSystem", tempUseSystem);
@@ -177,8 +178,6 @@ void QDltSettingsManager::writeSettings()
     settings->setValue("startup/pluginsAutoloadPath",pluginsAutoloadPath);
     settings->setValue("startup/pluginsAutoloadPathName",pluginsAutoloadPathName);
     settings->setValue("startup/filterCache",filterCache);
-    settings->setValue("startup/filterCacheDays",filterCacheDays);
-    settings->setValue("startup/filterCacheName",filterCacheName);
     settings->setValue("startup/autoConnect",autoConnect);
     settings->setValue("startup/autoScroll",autoScroll);
     settings->setValue("startup/autoMarkFatalError",autoMarkFatalError);
@@ -226,9 +225,13 @@ void QDltSettingsManager::writeSettings()
     settings->setValue("startup/msgIdFormat",msgIdFormat);
 
     /* For settings integrity validation */
-    settings->setValue("startup/versionMajor", QString(PACKAGE_MAJOR_VERSION).toInt());
-    settings->setValue("startup/versionMinor", QString(PACKAGE_MINOR_VERSION).toInt());
-    settings->setValue("startup/versionPatch", QString(PACKAGE_PATCH_LEVEL).toInt());
+    settings->setValue("startup/versionMajor", PACKAGE_MAJOR_VERSION);
+    settings->setValue("startup/versionMinor", PACKAGE_MINOR_VERSION);
+    settings->setValue("startup/versionPatch", PACKAGE_PATCH_LEVEL);
+
+    for(int i = 0; i < pluginExecutionPrio.count(); ++i) {
+        settings->setValue(QStringLiteral("plugin/default_prio/%1").arg(i), pluginExecutionPrio[i]);
+    }
 }
 
 void QDltSettingsManager::readSettingsLocal(QXmlStreamReader &xml)
@@ -409,6 +412,7 @@ void QDltSettingsManager::readSettings()
 
     RefreshRate = settings->value("RefreshRate",DEFAULT_REFRESH_RATE).toInt();
     StartupMinimized = settings->value("StartupMinimized",0).toInt();
+    themeSelectionSettings = static_cast<UI_Colour>(settings->value("ThemeSettings", 0).toInt());
 
     /* startup */
     defaultProjectFile = settings->value("startup/defaultProjectFile",0).toInt();
@@ -422,8 +426,6 @@ void QDltSettingsManager::readSettings()
     pluginsAutoloadPath = settings->value("startup/pluginsAutoloadPath",0).toInt();
     pluginsAutoloadPathName = settings->value("startup/pluginsAutoloadPathName",QString("")).toString();
     filterCache = settings->value("startup/filterCache",1).toInt();
-    filterCacheDays = settings->value("startup/filterCacheDays",7).toInt();
-    filterCacheName = settings->value("startup/filterCacheName",QStandardPaths::writableLocation(QStandardPaths::CacheLocation)+"/indexcache").toString();
     autoConnect = settings->value("startup/autoConnect",0).toInt();
     autoScroll = settings->value("startup/autoScroll",1).toInt();
     autoMarkFatalError = settings->value("startup/autoMarkFatalError",0).toInt();
@@ -471,5 +473,14 @@ void QDltSettingsManager::readSettings()
     updateContextLoadingFile = settings->value("startup/updateContextLoadingFile",1).toInt();
     updateContextsUnregister = settings->value("startup/updateContextsUnregister",0).toInt();
     msgIdFormat = settings->value("startup/msgIdFormat","[%08u]").toString();
+
+    // Read the plugin execution priority of a maximum of 100 plugins
+    for(int i = 0; i < 100; ++i)
+    {
+        QString lastValue(settings->value(QStringLiteral("plugin/default_prio/%1").arg(i),"").toString());
+        if( !lastValue.isEmpty() ) {
+            pluginExecutionPrio << lastValue;
+        }
+    }
 }
 
