@@ -8,6 +8,8 @@
 #include <QTime>
 #include <QCryptographicHash>
 #include <QMutexLocker>
+#include <QDir>
+#include <QFileInfo>
 
 
 extern "C" {
@@ -51,6 +53,10 @@ DltFileIndexer::DltFileIndexer(QObject *parent) :
     msecsIndexCounter = 0;
     msecsFilterCounter = 0;
     msecsDefaultFilterCounter = 0;
+
+    filterIndexEnabled = false;
+    filterIndexStart = 0;
+    filterIndexEnd = 0;
 }
 
 DltFileIndexer::DltFileIndexer(QDltFile *dltFile, QDltPluginManager *pluginManager, QDltDefaultFilter *defaultFilter, QMainWindow *parent) :
@@ -74,6 +80,10 @@ DltFileIndexer::DltFileIndexer(QDltFile *dltFile, QDltPluginManager *pluginManag
     msecsIndexCounter = 0;
     msecsFilterCounter = 0;
     msecsDefaultFilterCounter = 0;
+
+    filterIndexEnabled = false;
+    filterIndexStart = 0;
+    filterIndexEnd = 0;
 }
 
 DltFileIndexer::~DltFileIndexer()
@@ -87,7 +97,7 @@ bool DltFileIndexer::index(int num)
     // time.start();
 
     // load filter index if enabled
-    if(!filterCache.isEmpty() && loadIndexCache(dltFile->getFileName(num)))
+    if(filterCacheEnabled && loadIndexCache(dltFile->getFileName(num)))
     {
         // loading index from filter is succesful
         qDebug() << "Successfully loaded index cache for file" << dltFile->getFileName(num);// << __LINE__;
@@ -312,10 +322,10 @@ bool DltFileIndexer::index(int num)
     }
 
     // write index if enabled
-    if(false == filterCache.isEmpty())
+    if(filterCacheEnabled)
     {
         saveIndexCache(dltFile->getFileName(num));
-        qDebug() << "Saved index cache for file" << dltFile->getFileName(num) << filterCache;
+        qDebug() << "Saved index cache for file" << dltFile->getFileName(num);
     }
     emit(progress(pos));
 
@@ -335,7 +345,7 @@ bool DltFileIndexer::indexFilter(QStringList filenames)
     QSharedPointer<QDltMsg> msg;
     QDltFilterList filterList;
     QTime time;
-    qint64 ix = 0;
+    quint64 ix = 0;
     unsigned int iPercent = 0;
 
     // start performance counter
@@ -348,8 +358,29 @@ bool DltFileIndexer::indexFilter(QStringList filenames)
     indexFilterListSorted.clear();
     getLogInfoList.clear();
 
+    // calculate start and end index
+    quint64 start,end;
+    if(!filterIndexEnabled)
+    {
+        start = 0;
+        end = dltFile->size();
+    }
+    else
+    {
+        if(filterIndexStart<=dltFile->size())
+            start = filterIndexStart;
+        else
+            start = 0;
+        if(filterIndexEnd<=dltFile->size())
+            end = filterIndexEnd + 1;
+        else
+            end = dltFile->size();
+        if(start>end)
+            start=end;
+    }
+
     // load filter index, if enabled and not an initial loading of file
-    if(!filterCache.isEmpty() && mode != modeIndexAndFilter && loadFilterIndexCache(filterList,indexFilterList,filenames))
+    if(filterCacheEnabled && mode != modeIndexAndFilter && loadFilterIndexCache(filterList,indexFilterList,filenames))
     {
         // loading filter index from filter is succesful
         qDebug() << "Loaded filter index cache for files" << filenames;
@@ -402,7 +433,7 @@ bool DltFileIndexer::indexFilter(QStringList filenames)
     }
 
     // Start reading messages
-    for(ix=0;ix<dltFile->size();ix++)
+    for(ix=start;ix<end;ix++)
     {
         msg = QSharedPointer<QDltMsg>::create(); // create new instance to be filled by getMsg(), otherwise shared pointer would be empty or pointing to last message
 
@@ -422,7 +453,7 @@ bool DltFileIndexer::indexFilter(QStringList filenames)
         if  (ix > 0 )
         if( 0 == (ix % modvalue) )
         {
-         iPercent = ( ix*100 )/dltFile->size();
+         iPercent = ( (ix-start)*100 )/(end-start);
          if( ( true == QDltOptManager::getInstance()->issilentMode() ) )
          {
              qDebug().noquote() << "IF Indexed:" << iPercent << "%";
@@ -461,7 +492,7 @@ bool DltFileIndexer::indexFilter(QStringList filenames)
         indexFilterList = QVector<qint64>::fromList(indexFilterListSorted.values());
 
     // write filter index if enabled
-    if(!filterCache.isEmpty())
+    if(filterCacheEnabled)
     {
         saveFilterIndexCache(filterList, indexFilterList, filenames);
         qDebug() << "Saved filter index cache for files" << filenames;
@@ -562,7 +593,7 @@ bool DltFileIndexer::indexDefaultFilter()
         filterIndex->setAllIndexSize(dltFile->size());
 
         // write filter index if enabled
-        if(!filterCache.isEmpty())
+        if(filterCacheEnabled)
             saveFilterIndexCache(*filterList, filterIndex->indexFilter, QStringList(dltFile->getFileName()));
     }
 
@@ -647,7 +678,7 @@ void DltFileIndexer::run()
     {
         QStringList filenames;
         for(int num=0;num<dltFile->getNumberOfFiles();num++)
-            filenames.append(QFileInfo(dltFile->getFileName(num)).fileName());
+            filenames.append(dltFile->getFileName(num));
         if((mode != modeNone) && !indexFilter(filenames))
         {
             // error
@@ -682,6 +713,36 @@ void DltFileIndexer::run()
     */
 }
 
+bool DltFileIndexer::getFilterIndexEnabled() const
+{
+    return filterIndexEnabled;
+}
+
+void DltFileIndexer::setFilterIndexEnabled(bool newFilterIndexEnabled)
+{
+    filterIndexEnabled = newFilterIndexEnabled;
+}
+
+qint64 DltFileIndexer::getFilterIndexStart() const
+{
+    return filterIndexStart;
+}
+
+void DltFileIndexer::setFilterIndexStart(qint64 newFilterIndexStart)
+{
+    filterIndexStart = newFilterIndexStart;
+}
+
+qint64 DltFileIndexer::getFilterIndexEnd() const
+{
+    return filterIndexEnd;
+}
+
+void DltFileIndexer::setFilterIndexEnd(qint64 newFilterIndexEnd)
+{
+    filterIndexEnd = newFilterIndexEnd;
+}
+
 void DltFileIndexer::stop()
 {
     // stop the thread
@@ -696,14 +757,19 @@ bool DltFileIndexer::loadIndexCache(QString filename)
     QString filenameCache;
 
     // check if caching is enabled
-    if(filterCache.isEmpty())
+    if(!filterCacheEnabled)
         return false;
 
     // get the filename for the cache file
     filenameCache = filenameIndexCache(filename);
 
-    // load the cache file
-    if(!loadIndex(filterCache + "/" +filenameCache,indexAllList))
+    // load the cache file in a subdirectory index
+    QFileInfo info(filename);
+    QDir dir(info.dir().path()+"/index");
+    if (!dir.exists())
+        dir.mkpath(".");
+    qDebug() << "Index Cache filename" << info.dir().path() + "/index/" +filenameCache;
+    if(!loadIndex(info.dir().path() + "/index/" +filenameCache,indexAllList))
     {
         // loading cache file failed
         return false;
@@ -717,14 +783,19 @@ bool DltFileIndexer::saveIndexCache(QString filename)
     QString filenameCache;
 
     // check if caching is enabled
-    if(filterCache.isEmpty())
+    if(!filterCacheEnabled)
         return false;
 
     // get the filename for the cache file
     filenameCache = filenameIndexCache(filename);
 
-    // save the cache file
-    if(!saveIndex(filterCache + "/" +filenameCache,indexAllList))
+    // save the cache file in a sudirectory index
+    QFileInfo info(filename);
+    QDir dir(info.dir().path()+"/index");
+    if (!dir.exists())
+        dir.mkpath(".");
+    qDebug() << "Index Cache filename" << info.dir().path() + "/index/" +filenameCache;
+    if(!saveIndex(info.dir().path() + "/index/" +filenameCache,indexAllList))
     {
         // saving cache file failed
         return false;
@@ -764,21 +835,24 @@ bool DltFileIndexer::loadFilterIndexCache(QDltFilterList &filterList, QVector<qi
     QString filenameCache;
 
     // check if caching is enabled
-    if(filterCache.isEmpty())
+    if(!filterCacheEnabled)
         return false;
 
     // get the filename for the cache file
     filenameCache = filenameFilterIndexCache(filterList,filenames);
 
     // load the cache file
-    //qDebug() << "loadIndex" << __LINE__;
-    if(loadIndex(filterCache + "/" +filenameCache,index))
+    QFileInfo info(filenames[0]);
+    QDir dir(info.dir().path()+"/index");
+    if (!dir.exists())
+        dir.mkpath(".");
+    if(loadIndex(info.dir().path() + "/index/" +filenameCache,index))
     {
-        qDebug() << "loadIndex" << filterCache + "/" +filenameCache << "success";
+        qDebug() << "loadIndex" << info.dir().path() + "/index/" +filenameCache << "success";
     }
     else
     {
-        qDebug() << "loadIndex" << filterCache + "/" +filenameCache << "failed";
+        qDebug() << "loadIndex" << info.dir().path() + "/index/" +filenameCache << "failed";
         return false;
     }
 
@@ -790,14 +864,19 @@ bool DltFileIndexer::saveFilterIndexCache(QDltFilterList &filterList, QVector<qi
     QString filename;
 
     // check if caching is enabled
-    if(filterCache.isEmpty())
+    if(!filterCacheEnabled)
         return false;
 
     // get the filename for the cache file
     filename = filenameFilterIndexCache(filterList,filenames);
 
     // save the cache file
-    if(!saveIndex(filterCache + "/" +filename,index))
+    QFileInfo info(filenames[0]);
+    QDir dir(info.dir().path()+"/index");
+    if (!dir.exists())
+        dir.mkpath(".");
+    qDebug() << "Filter Index Cache filename" << info.dir().path() + "/index/" +filename;
+    if(!saveIndex(info.dir().path() + "/index/" +filename,index))
     {
         // saving of cache file failed
         return false;
@@ -866,6 +945,10 @@ QString DltFileIndexer::filenameFilterIndexCache(QDltFilterList &filterList,QStr
     {
         filename += "_STS";
     }
+    if(this->filterIndexEnabled)
+    {
+        filename += QString("_%1_%2").arg(this->filterIndexStart).arg(this->filterIndexEnd);
+    }
     filename += ".dix";
 
     return filename;
