@@ -2,9 +2,9 @@
  * @licence app begin@
  * Copyright (C) 2011-2012  BMW AG
  *
- * This file is part of GENIVI Project Dlt Viewer.
+ * This file is part of COVESA Project Dlt Viewer.
  *
- * Contributions are licensed to the GENIVI Alliance under one or more
+ * Contributions are licensed to the COVESA Alliance under one or more
  * Contribution License Agreements.
  *
  * \copyright
@@ -13,7 +13,7 @@
  * this file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * \file mainwindow.h
- * For further information see http://www.genivi.org/.
+ * For further information see http://www.covesa.global/.
  * @licence end@
  */
 
@@ -41,6 +41,7 @@
 #include "workingdirectory.h"
 #include "exporterdialog.h"
 #include "searchtablemodel.h"
+#include "sortfilterproxymodel.h"
 #include "ui_mainwindow.h"
 
 
@@ -202,7 +203,6 @@ private:
     enum { MaxRecentHostnames = 10 };
     QStringList recentHostnames;
     enum { MaxRecentPorts = 10 };
-    QStringList recentSerialPorts;
     QStringList recentIPPorts;
     QStringList recentUDPPorts;
     QString recentEthIF;
@@ -237,6 +237,9 @@ private:
 
     QList<unsigned long int> selectedMarkerRows;
 
+    /**/
+    SortFilterProxyModel *sortProxyModel;
+
     /* functions called in constructor */
     void initState();
     void initView();
@@ -258,8 +261,8 @@ private:
 
     void reloadLogFileDefaultFilter();
 
-    void exportSelection(bool ascii,bool file,bool payload_only);
-    void exportSelection_searchTable(bool payload_only);
+    void exportSelection(bool ascii,bool file,DltExporter::DltExportFormat format);
+    void exportSelection_searchTable(DltExporter::DltExportFormat format);
 
     void ControlServiceRequest(EcuItem* ecuitem, int service_id );
     void SendInjection(EcuItem* ecuitem);
@@ -298,7 +301,7 @@ private:
     void updateIndex();
     void drawUpdatedView();
 
-     void syncCheckBoxesAndMenu();
+    void syncCheckBoxesAndMenu();
 
     void updateRecentFileActions();
     void setCurrentFile(const QString &fileName);
@@ -315,7 +318,6 @@ private:
 
     void setCurrentHostname(const QString &hostName);
     void setCurrentMCAddress(const QString &mcastaddress);
-    void setCurrentSerialPort(const QString &portName);
     void setCurrentIPPort(const QString &portName);
     void setCurrentUDPPort(const QString &portName);
     void setCurrentEthIF(const QString &EthIfName);
@@ -330,6 +332,8 @@ private:
     bool openDlpFile(QString filename);
     bool openDlfFile(QString filename, bool replace);
 
+    void appendDltFile(const QString &fileName);
+
     void commandLineConvertToASCII();
     void commandLineConvertToDLT();
     void commandLineConvertToUTF8();
@@ -376,6 +380,9 @@ private:
 
     QStringListModel m_CompleterModel;
 
+    /* Get path from explorerView model index */
+    QString getPathFromExplorerViewIndexModel(const QModelIndex &proxyIndex);
+
 protected:
     void keyPressEvent ( QKeyEvent * event );
     void dragEnterEvent(QDragEnterEvent *event);
@@ -400,6 +407,7 @@ private slots:
     void on_pluginWidget_customContextMenuRequested(QPoint pos);
     void on_filterWidget_customContextMenuRequested(QPoint pos);
     void on_configWidget_customContextMenuRequested(QPoint pos);
+    void on_exploreView_customContextMenuRequested(QPoint pos);
 
     void on_configWidget_itemSelectionChanged();
     void on_pluginWidget_itemSelectionChanged();
@@ -409,6 +417,8 @@ private slots:
 
     void on_pluginWidget_itemExpanded(QTreeWidgetItem* item);
 
+    void on_pluginWidget_pluginPriorityChanged(const QString name, int prio);
+
 // File methods
 
 private slots:
@@ -422,6 +432,9 @@ private slots:
     void on_action_menuFile_Open_triggered();
     void on_actionExport_triggered();
 
+    void on_pushButtonMovePluginUp_clicked();
+    void on_pushButtonMovePluginDown_clicked();
+
 public slots:
 
     void onNewTriggered(QString fileName);
@@ -433,7 +446,8 @@ public slots:
     void on_actionFindNext();
     void mark_unmark_lines();
     void unmark_all_lines();
-
+    void filterIndexStart();
+    void filterIndexEnd();
 
 private slots:
 
@@ -470,8 +484,14 @@ private slots:
     void on_action_menuConfig_Delete_All_Contexts_triggered();
     void onActionAenuConfigCopyPayloadToClipboardTriggered();
     void on_action_menuConfig_Copy_to_clipboard_triggered();
+    void onActionMenuConfigCopyJiraToClipboardTriggered();
+    void onActionMenuConfigCopyJiraHeadToClipboardTriggered();
     void onActionMenuConfigSearchTableCopyToClipboardTriggered();
     void onActionMenuConfigSearchTableCopyPayloadToClipboardTriggered();
+    void onActionMenuConfigSearchTableCopyJiraToClipboardTriggered();
+    void onActionMenuConfigSearchTableCopyJiraHeadToClipboardTriggered();
+
+    void on_action_menuConfig_Save_All_ECUs_triggered();
 
     // DLT methods
     void on_action_menuDLT_Send_Injection_triggered();
@@ -557,14 +577,29 @@ private slots:
     void on_actionToggle_SortByTimeEnabled_triggered(bool checked);
     void on_actionSort_By_Timestamp_triggered(bool checked);
 
+    void on_exploreView_activated(const QModelIndex &index);
+
+    void on_comboBoxExplorerSortType_currentIndexChanged(int index);
+
+    void on_comboBoxExplorerSortOrder_currentIndexChanged(int index);
+
+    void on_checkBoxFilterRange_stateChanged(int arg1);
+
+    void on_lineEditFilterStart_textChanged(const QString &arg1);
+
+    void on_lineEditFilterEnd_textChanged(const QString &arg1);
+
 public slots:
 
     void sendInjection(int index,QString applicationId,QString contextId,int serviceId,QByteArray data);
     void filterOrderChanged();
+    void filterCountChanged();
     void jumpToMsgSignal(int index);
     void markerSignal();
     void connectEcuSignal(int index);
     void disconnectEcuSignal(int index);
+    void connectAllEcuSignal();
+    void disconnectAllEcuSignal();
     void reopenFileSignal();
 
     void controlMessage_Timezone(int timezone, unsigned char dst);
@@ -593,6 +628,8 @@ public:
     /* store startLoggingDateTime when logging first data */
     QDateTime startLoggingDateTime;
 
+signals:
+    void dltFileLoaded(const QStringList& paths);
 
 };
 
