@@ -2,9 +2,9 @@
  * @licence app begin@
  * Copyright (C) 2011-2012  BMW AG
  *
- * This file is part of GENIVI Project Dlt Viewer.
+ * This file is part of COVESA Project Dlt Viewer.
  *
- * Contributions are licensed to the GENIVI Alliance under one or more
+ * Contributions are licensed to the COVESA Alliance under one or more
  * Contribution License Agreements.
  *
  * \copyright
@@ -13,7 +13,7 @@
  * this file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * \file settingsdialog.cpp
- * For further information see http://www.genivi.org/.
+ * For further information see http://www.covesa.global/.
  * @licence end@
  */
 
@@ -157,7 +157,7 @@ void SettingsDialog::assertSettingsVersion()
         return; // The settings were empty already
     }
 
-   if(major > QString(PACKAGE_MAJOR_VERSION).toInt() || minor > QString(PACKAGE_MINOR_VERSION).toInt())
+   if(major > PACKAGE_MAJOR_VERSION || minor > PACKAGE_MINOR_VERSION)
     {
         QString msg;
         msg.append("The application version has changed ! The settings file config.ini might be incompatible.\n");
@@ -235,8 +235,6 @@ void SettingsDialog::writeDlg()
     ui->checkBoxPluginsAutoload->setCheckState(settings->pluginsAutoloadPath?Qt::Checked:Qt::Unchecked);
     ui->lineEditPluginsAutoload->setText(settings->pluginsAutoloadPathName);
     ui->checkBoxFilterCache->setCheckState(settings->filterCache?Qt::Checked:Qt::Unchecked);
-    ui->spinBoxIndexCacheDays->setValue(settings->filterCacheDays);
-    ui->lineEditFilterCache->setText(settings->filterCacheName);
     ui->checkBoxAutoConnect->setCheckState(settings->autoConnect?Qt::Checked:Qt::Unchecked);
     ui->checkBoxAutoScroll->setCheckState(settings->autoScroll?Qt::Checked:Qt::Unchecked);
     ui->checkBoxAutoMarkFatalError->setCheckState(settings->autoMarkFatalError?Qt::Checked:Qt::Unchecked);
@@ -378,6 +376,8 @@ void SettingsDialog::writeDlg()
     ui->spinBoxFrequency->setValue(settings->RefreshRate);
     ui->checkBoxStartUpMinimized->setChecked(settings->StartupMinimized);
     ui->comboBox_MessageIdFormat->setCurrentText(settings->msgIdFormat);
+
+    ui->comboBoxTheme->setCurrentIndex(static_cast<int>(settings->themeSelectionSettings));
 }
 
 void SettingsDialog::readDlg()
@@ -404,8 +404,6 @@ void SettingsDialog::readDlg()
     settings->pluginsAutoloadPath = (ui->checkBoxPluginsAutoload->checkState() == Qt::Checked);
     settings->pluginsAutoloadPathName = ui->lineEditPluginsAutoload->text();
     settings->filterCache = (ui->checkBoxFilterCache->checkState() == Qt::Checked);
-    settings->filterCacheDays = ui->spinBoxIndexCacheDays->value();
-    settings->filterCacheName = ui->lineEditFilterCache->text();
     settings->autoConnect = (ui->checkBoxAutoConnect->checkState() == Qt::Checked);
     settings->autoScroll = (ui->checkBoxAutoScroll->checkState() == Qt::Checked);
     settings->autoMarkFatalError = (ui->checkBoxAutoMarkFatalError->checkState() == Qt::Checked);
@@ -465,6 +463,18 @@ void SettingsDialog::readDlg()
     settings->RefreshRate = ui->spinBoxFrequency->value();
     settings->StartupMinimized = ui->checkBoxStartUpMinimized->isChecked();
     settings->msgIdFormat=ui->comboBox_MessageIdFormat->currentText();
+
+    auto prevUISettings = settings->themeSelectionSettings;
+    settings->themeSelectionSettings = static_cast<QDltSettingsManager::UI_Colour>(ui->comboBoxTheme->currentIndex());
+
+    if (prevUISettings != settings->themeSelectionSettings)
+    {
+        QMessageBox msgBox(QMessageBox::Warning,
+                           "Settings updated",
+                           "Restart the application for changes to take effect",
+                           QMessageBox::Ok);
+        msgBox.exec();
+    }
 }
 
 void SettingsDialog::writeSettings(QMainWindow *mainwindow)
@@ -488,6 +498,23 @@ void SettingsDialog::readSettings()
     palette.setColor(QPalette::Active,this->backgroundRole(),settings->markercolor);
     ui->labelSelectedMarkerColor->setPalette(palette);
 
+    auto uiColour = settings->themeSelectionSettings;
+
+    if (QDltSettingsManager::UI_Colour::UI_SystemDefault == uiColour)
+    {
+        uiColour = QDltSettingsManager::UI_Colour::UI_Light;
+
+#ifdef Q_OS_WIN
+        QSettings themeSettings("HKEY_CURRENT_USER\\Software\\Microsoft\\Windows\\CurrentVersion\\Themes\\Personalize",QSettings::NativeFormat);
+
+        if(themeSettings.value("AppsUseLightTheme")==0)
+        {
+            uiColour = QDltSettingsManager::UI_Colour::UI_Dark;
+        }
+#endif
+    }
+
+    settings->uiColour = uiColour;
 }
 
 
@@ -602,22 +629,6 @@ void SettingsDialog::on_toolButtonPluginsAutoload_clicked()
     ui->lineEditPluginsAutoload->setText(fileName);
 }
 
-
-void SettingsDialog::on_toolButtonFilterCache_clicked()
-{
-    QString fileName = QFileDialog::getExistingDirectory(this,
-        tr("Filter Cache directory"), workingDirectory+"/", QFileDialog::ShowDirsOnly | QFileDialog::DontResolveSymlinks);
-
-    if(fileName.isEmpty())
-        return;
-
-    /* change current working directory */
-    QDltSettingsManager *settings = QDltSettingsManager::getInstance();
-    settings->filterCacheName = QFileInfo(fileName).absolutePath();
-
-    ui->lineEditFilterCache->setText(fileName);
-}
-
 void SettingsDialog::on_groupBoxConId_clicked(bool checked)
 {
     if(checked){
@@ -669,66 +680,6 @@ void SettingsDialog::on_groupBoxAutomaticTimeSettings_clicked(bool checked)
     }
 }
 
-
-void SettingsDialog::on_pushButtonClearIndexCache_clicked()
-{
-    QString path = ui->lineEditFilterCache->text();
-    QDir dir(path);
-    dir.setNameFilters(QStringList() << "*.dix");
-    dir.setFilter(QDir::Files);
-    foreach(QString dirFile, dir.entryList())
-    {
-        dir.remove(dirFile);
-    }
-}
-
-void SettingsDialog::clearIndexCacheAfterDays()
-{
-    QDltSettingsManager *settings = QDltSettingsManager::getInstance();
-
-    // calculate comparison date
-    QDateTime comparisonDate(QDateTime::currentDateTime());
-    comparisonDate = comparisonDate.addSecs((quint64)settings->filterCacheDays*-1*60*60*24);
-
-    // check if index cache is enabled
-    if(0 == settings->filterCache)
-    {
-        return;
-    }
-
-    /* check if directory for configuration exists */
-    QString path = settings->filterCacheName;
-    QDir dir(path);
-    if(!dir.exists())
-    {
-        /* directory does not exist, make it */
-        if(!dir.mkpath(dir.absolutePath()))
-        {
-            /* creation of directory fails */
-            QMessageBox::critical(0, QString("DLT Viewer"),
-                                           QString("Cannot create directory to store index cache files!\n\n")+dir.absolutePath(),
-                                           QMessageBox::Ok,
-                                           QMessageBox::Ok);
-        }
-        return;
-    }
-
-    // go through each file and check modification date of file
-    dir.setNameFilters(QStringList() << "*.dix");
-    dir.setFilter(QDir::Files);
-    foreach(QString dirFile, dir.entryList())
-    {
-        QFileInfo info(path+"/"+dirFile);
-        QDateTime fileDate = info.lastRead();
-
-        //qDebug() << fileDate.toString("dd.MM.yyyy hh:mm:ss.zzz") << comparisonDate.toString("dd.MM.yyyy hh:mm:ss.zzz");
-
-        if(fileDate < comparisonDate)
-            dir.remove(dirFile);
-    }
-}
-
-
 void SettingsDialog::on_checkBoxPluginsAutoload_stateChanged(int activated)
 {
    if ( activated != 0)
