@@ -2,9 +2,9 @@
  * @licence app begin@
  * Copyright (C) 2011-2012  BMW AG
  *
- * This file is part of GENIVI Project Dlt Viewer.
+ * This file is part of COVESA Project Dlt Viewer.
  *
- * Contributions are licensed to the GENIVI Alliance under one or more
+ * Contributions are licensed to the COVESA Alliance under one or more
  * Contribution License Agreements.
  *
  * \copyright
@@ -13,7 +13,7 @@
  * this file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * \file treemodel.cpp
- * For further information see http://www.genivi.org/.
+ * For further information see http://www.covesa.global/.
  * @licence end@
  */
 
@@ -332,13 +332,13 @@ TableModel::TableModel(const QString & /*data*/, QObject *parent)
 
      if ( role == Qt::TextAlignmentRole )
      {
-         switch(index.column())
+        /*switch(index.column())
         {
             //case FieldNames::Index: return QVariant(Qt::AlignRight  | Qt::AlignVCenter);
             default:
-                  return FieldNames::getColumnAlignment((FieldNames::Fields)index.column(),project->settings);
 
-        }
+        }*/
+        return FieldNames::getColumnAlignment((FieldNames::Fields)index.column(),project->settings);
     }
 
      return QVariant();
@@ -355,12 +355,12 @@ QVariant TableModel::headerData(int section, Qt::Orientation orientation,
             return FieldNames::getName((FieldNames::Fields)section, project->settings);
         case Qt::TextAlignmentRole:
             {
-            switch(section)
+            /*switch(section)
                 {
                  //case FieldNames::Payload: return QVariant(Qt::AlignRight  | Qt::AlignVCenter);
-                  default:return FieldNames::getColumnAlignment((FieldNames::Fields)section,project->settings);
-                }
-
+                default:
+                }*/
+            return FieldNames::getColumnAlignment((FieldNames::Fields)section,project->settings);
             }
          default:
             break;
@@ -465,6 +465,12 @@ QSize HtmlDelegate::sizeHint(const QStyleOptionViewItem &option, const QModelInd
 
 QColor TableModel::getMsgBackgroundColor(QDltMsg &msg,int index,long int filterposindex) const
 {
+    /* first check manual markers with highest priority */
+    if ( selectedMarkerRows.contains(index) )
+    {
+      return manualMarkerColor;
+    }
+
     /* get check marker color */
     QColor color = qfile->checkMarker(msg);
     if(color.isValid())
@@ -482,10 +488,6 @@ QColor TableModel::getMsgBackgroundColor(QDltMsg &msg,int index,long int filterp
         {
           return searchhit_higlightColor;
         }
-        if ( selectedMarkerRows.contains(index) )
-        {
-          return manualMarkerColor;
-        }
         if(project->settings->autoMarkFatalError && ( msg.getSubtypeString() == "error" || msg.getSubtypeString() == "fatal") )
         {
            /* If automark error is enabled, set red as background color */
@@ -505,5 +507,12 @@ QColor TableModel::getMsgBackgroundColor(QDltMsg &msg,int index,long int filterp
     }
 
     /* default return white background color */
-    return QColor(255,255,255); // this is the default background clor
+    QColor brushColor = QColor(255,255,255);
+
+    if (QDltSettingsManager::UI_Colour::UI_Dark == QDltSettingsManager::getInstance()->uiColour)
+    {
+        brushColor = QColor(31,31,31);
+    }
+
+    return brushColor; // this is the default background color
 }
